| heap_grid | R Documentation |
The leading tooth of the power spectrum sits at 2*pi/D, so the grid is
Dhat = 2*pi / w_peak.
heap_grid(y, grid, near = NULL)
y |
heaped (rounded) sample. |
grid |
evaluation grid (equally spaced). |
near |
optional grid hint; if supplied the tooth is located in a frequency window
around |
The recovered grid width Dhat (or NA if no tooth is found).
grid <- seq(-6, 6, length.out = 2048)
x <- ifelse(runif(4000) < 0.5, rnorm(4000, -1.2, 0.5), rnorm(4000, 1.2, 0.5))
heap_grid(0.5 * round(x / 0.5), grid, near = 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.